Module error

Module error 

Error types for the SQL Stream library

This module defines all error types used throughout the library using thiserror for ergonomic error handling and proper error propagation.

Enums

SqlStreamError
Main error type for SQL Stream operations

Type Aliases

Result
Type alias for Results using SqlStreamError